# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`ejbca`](#ejbca): Installs and configures EJBCA
* [`ejbca::api_config`](#ejbcaapi_config): Configure access to the EJBCA API
* [`ejbca::config`](#ejbcaconfig): Configure EJBCA
* [`ejbca::install`](#ejbcainstall): Install EJBCA
* [`ejbca::wildfly::config`](#ejbcawildflyconfig): Configure Wildfly
* [`ejbca::wildfly::install`](#ejbcawildflyinstall): Install Wildfly

### Defined types

* [`ejbca::wildfly::interface`](#ejbcawildflyinterface): Create a Wildfly interface and socket-binding

### Resource types

* [`ejbca_end_entity`](#ejbca_end_entity): Username

### Functions

* [`ejbca::database_driver_params`](#ejbcadatabase_driver_params)
* [`ejbca::database_url`](#ejbcadatabase_url)

### Data types

* [`Ejbca::Database_driver`](#ejbcadatabase_driver)
* [`Ejbca::Database_driver_params`](#ejbcadatabase_driver_params)

## Classes

### <a name="ejbca"></a>`ejbca`

Installs and configures EJBCA

#### Examples

##### Minimal usage

```puppet
include ejbca
```

#### Parameters

The following parameters are available in the `ejbca` class:

* [`wildfly_version`](#wildfly_version)
* [`user`](#user)
* [`group`](#group)
* [`home`](#home)
* [`ejbca_source`](#ejbca_source)
* [`ejbca_basename`](#ejbca_basename)
* [`ejbca_install_dir`](#ejbca_install_dir)
* [`database_driver`](#database_driver)
* [`database_driver_params`](#database_driver_params)
* [`db`](#db)
* [`db_user`](#db_user)
* [`db_password`](#db_password)
* [`database_url`](#database_url)
* [`keystore_password`](#keystore_password)
* [`organization`](#organization)
* [`country`](#country)
* [`superadmin_cn`](#superadmin_cn)
* [`superadmin_password`](#superadmin_password)
* [`api_client_cert_filename`](#api_client_cert_filename)
* [`api_client_cert_path`](#api_client_cert_path)
* [`api_client_cert_password`](#api_client_cert_password)
* [`vhost_name`](#vhost_name)
* [`java_home`](#java_home)
* [`java_xms`](#java_xms)
* [`java_xmx`](#java_xmx)
* [`java_opts`](#java_opts)
* [`add_datasource`](#add_datasource)
* [`wildfly_reload_retries`](#wildfly_reload_retries)
* [`wildfly_reload_wait`](#wildfly_reload_wait)

##### <a name="wildfly_version"></a>`wildfly_version`

Data type: `String`

The version of Wildfly to use.

Default value: `'10.1.0'`

##### <a name="user"></a>`user`

Data type: `String`

The user Wildfly runs as.

Default value: `'ejbca'`

##### <a name="group"></a>`group`

Data type: `String`

The group Wildfly runs as.

Default value: `'ejbca'`

##### <a name="home"></a>`home`

Data type: `Stdlib::Absolutepath`

The home directory of [user](#user), as an absolute path.

Default value: `"/home/${user}"`

##### <a name="ejbca_source"></a>`ejbca_source`

Data type: `Stdlib::Httpurl`

The url to download the EJBCA source from.

Default value: `'https://sourceforge.net/projects/ejbca/files/ejbca6/ejbca_6_15_2_6/ejbca_ce_6_15_2_6.zip'`

##### <a name="ejbca_basename"></a>`ejbca_basename`

Data type: `String`

The basename of the source, without extension

Default value: `basename($ejbca_source, '.zip')`

##### <a name="ejbca_install_dir"></a>`ejbca_install_dir`

Data type: `Stdlib::Absolutepath`

The absolute path to the directory the EJBCA source is unpacked to.

Default value: `"${home}/${ejbca_basename}"`

##### <a name="database_driver"></a>`database_driver`

Data type: `Ejbca::Database_driver`

The name of the database driver EJBCA will use.

Default value: `'h2'`

##### <a name="database_driver_params"></a>`database_driver_params`

Data type: `Ejbca::Database_driver_params`

The parameters required to add the [database driver](#database_driver) to Wildfly, as a hash.

Default value: `ejbca::database_driver_params($database_driver)`

##### <a name="db"></a>`db`

Data type: `String`

The name of the EJBCA database.

Default value: `'ejbca'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

The database user to access the EJBCA db.

Default value: `'ejbca'`

##### <a name="db_password"></a>`db_password`

Data type: `String`

The password for the [database user](#db_user).

Default value: `'ejbca'`

##### <a name="database_url"></a>`database_url`

Data type: `String`

The url to access the [EJBCA database](#db).

Default value: `ejbca::database_url($database_driver, $db)`

##### <a name="keystore_password"></a>`keystore_password`

Data type: `String`

The password protecting the Java keystore.

Default value: `'serverpwd'`

##### <a name="organization"></a>`organization`

Data type: `String`

Your organization.

Default value: `'EJBCA Sample'`

##### <a name="country"></a>`country`

Data type: `String`

Your country.

Default value: `'SE'`

##### <a name="superadmin_cn"></a>`superadmin_cn`

Data type: `String`

CN of the EJBCA SuperAdmin end entity.

Default value: `'SuperAdmin'`

##### <a name="superadmin_password"></a>`superadmin_password`

Data type: `String`

Password for the EJBCA SuperAdmin end entity.

Default value: `'ejbca'`

##### <a name="api_client_cert_filename"></a>`api_client_cert_filename`

Data type: `String`

The filename of the certificate that grants access to the EJBCA API.

Default value: `downcase($superadmin_cn)`

##### <a name="api_client_cert_path"></a>`api_client_cert_path`

Data type: `Stdlib::Absolutepath`

Absolute path to a certificate that grants access to the EJBCA API.

Default value: `"${ejbca_install_dir}/p12/${api_client_cert_filename}.p12"`

##### <a name="api_client_cert_password"></a>`api_client_cert_password`

Data type: `String`

Password protecting the certificate that grants access to the EJBCA API.

Default value: `'ejbca'`

##### <a name="vhost_name"></a>`vhost_name`

Data type: `Stdlib::Fqdn`

Name of the virtual host that EJBCA will use.

Default value: `$facts['fqdn']`

##### <a name="java_home"></a>`java_home`

Data type: `Stdlib::Absolutepath`

Absolute path to JAVA_HOME

Default value: `'/usr/lib/jvm/java-8-openjdk-amd64'`

##### <a name="java_xms"></a>`java_xms`

Data type: `String`

Value of the -Xms Java parameter

Default value: `'2048m'`

##### <a name="java_xmx"></a>`java_xmx`

Data type: `String`

Value of the -Xmx Java parameter

Default value: `'2048m'`

##### <a name="java_opts"></a>`java_opts`

Data type: `String`

Additional options to use with Java.

Default value: `'-Djava.net.preferIPv4Stack=true'`

##### <a name="add_datasource"></a>`add_datasource`

Data type: `Boolean`

Whether to add the EjbcaDS datasource

Default value: ``false``

##### <a name="wildfly_reload_retries"></a>`wildfly_reload_retries`

Data type: `Integer`

The number of retries to check if wildfly is available after a reload

Default value: `4`

##### <a name="wildfly_reload_wait"></a>`wildfly_reload_wait`

Data type: `Integer`

The delay in seconds between consecutive checks if wildfly is available after a reload

Default value: `30`

### <a name="ejbcaapi_config"></a>`ejbca::api_config`

Configure access to the EJBCA API

#### Examples

##### 

```puppet
include ejbca::api_config
```

### <a name="ejbcaconfig"></a>`ejbca::config`

Configure EJBCA

#### Examples

##### 

```puppet
include ejbca::config
```

### <a name="ejbcainstall"></a>`ejbca::install`

Install EJBCA

#### Examples

##### 

```puppet
include ejbca::install
```

### <a name="ejbcawildflyconfig"></a>`ejbca::wildfly::config`

Configure Wildfly

#### Examples

##### 

```puppet
include ejbca::wildfly::config
```

### <a name="ejbcawildflyinstall"></a>`ejbca::wildfly::install`

Install Wildfly

#### Examples

##### 

```puppet
include ejbca::wildfly::install
```

## Defined types

### <a name="ejbcawildflyinterface"></a>`ejbca::wildfly::interface`

Create a Wildfly interface and socket-binding

#### Examples

##### 

```puppet
ejbca::wildfly::interface { 'namevar': }
```

#### Parameters

The following parameters are available in the `ejbca::wildfly::interface` defined type:

* [`interface`](#interface)
* [`port`](#port)

##### <a name="interface"></a>`interface`

Data type: `String`



Default value: `$title`

##### <a name="port"></a>`port`

Data type: `Integer`



Default value: ``undef``

## Resource types

### <a name="ejbca_end_entity"></a>`ejbca_end_entity`

Username

#### Properties

The following properties are available in the `ejbca_end_entity` type.

##### `ca_name`

Issueing CA

##### `certificate_profile_name`

Certificate Profile

Default value: `ENDUSER`

##### `email`

Email address

##### `end_entity_profile_name`

End Entity Profile

Default value: `EMPTY`

##### `ensure`

Valid values: `present`, `absent`, `new`, `revoked`



Default value: `present`

##### `subject_alt_name`

Subject Alternative Names

Default value: `[]`

##### `subject_dn`

Subject DN

##### `token_type`

Valid values: `USERGENERATED`, `P12`, `JKS`, `PEM`

Token type

Default value: `USERGENERATED`

#### Parameters

The following parameters are available in the `ejbca_end_entity` type.

* [`clear_pwd`](#clear_pwd)
* [`password`](#password)
* [`provider`](#provider)
* [`revocation_reason`](#revocation_reason)
* [`username`](#username)

##### <a name="clear_pwd"></a>`clear_pwd`

Valid values: ``true``, ``false``, `yes`, `no`

Store password in clear text?

Default value: ``false``

##### <a name="password"></a>`password`

Password or enrollment code

##### <a name="provider"></a>`provider`

The specific backend to use for this `ejbca_end_entity` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="revocation_reason"></a>`revocation_reason`

Valid values: `aacompromise`, `affiliationchanged`, `cacompromise`, `certificatehold`, `cessationofoperation`, `keycompromise`, `privilegeswithdrawn`, `removefromcrl`, `superseded`, `unspecified`

Revocation reason

Default value: `unspecified`

##### <a name="username"></a>`username`

Username

## Functions

### <a name="ejbcadatabase_driver_params"></a>`ejbca::database_driver_params`

Type: Puppet Language

The ejbca::database_driver_params function.

#### `ejbca::database_driver_params(Ejbca::Database_driver $driver)`

The ejbca::database_driver_params function.

Returns: `Ejbca::Database_driver_params`

##### `driver`

Data type: `Ejbca::Database_driver`



### <a name="ejbcadatabase_url"></a>`ejbca::database_url`

Type: Puppet Language

The ejbca::database_url function.

#### `ejbca::database_url(Ejbca::Database_driver $driver, String $db)`

The ejbca::database_url function.

Returns: `String`

##### `driver`

Data type: `Ejbca::Database_driver`



##### `db`

Data type: `String`



## Data types

### <a name="ejbcadatabase_driver"></a>`Ejbca::Database_driver`

The Ejbca::Database_driver data type.

Alias of

```puppet
Enum['mariadb', 'mysql5', 'mysql8', 'postgresql', 'h2']
```

### <a name="ejbcadatabase_driver_params"></a>`Ejbca::Database_driver_params`

The Ejbca::Database_driver_params data type.

Alias of

```puppet
Struct[{
    database_name                   => Enum['db2', 'derby', 'h2', 'informix', 'ingres', 'mssql', 'mysql', 'oracle', 'postgres', 'sybase'],
    driver_module_name              => String,
    driver_module_source            => Variant[Pattern[/^\./], Pattern[/^file:\/\//], Pattern[/^puppet:\/\//], Stdlib::Httpurl],
    driver_name                     => String,
    driver_xa_datasource_class_name => String
  }]
```

